Atomic Data
===========

Contains atomic properties and constants for elements commonly found in PDB structures.

Module Overview
---------------

.. automodule:: hbat.constants.atomic_data
   :members:
   :undoc-members:
   :show-inheritance: